summaryrefslogtreecommitdiffstats
path: root/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
diff options
context:
space:
mode:
authorSamer El-Haj-Mahmoud <samer.el-haj-mahmoud@hp.com>2014-11-27 01:01:43 +0000
committererictian <erictian@Edk2>2014-11-27 01:01:43 +0000
commit01331951708f980fca1fb3a791ab544adcd3a5d0 (patch)
tree3768f07f468ebf5ffb918a52e36e33046b399ba5 /MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
parent2bf41ed7dc20f0f6e13babb136753ff3f91edd21 (diff)
downloadedk2-01331951708f980fca1fb3a791ab544adcd3a5d0.tar.gz
edk2-01331951708f980fca1fb3a791ab544adcd3a5d0.tar.bz2
edk2-01331951708f980fca1fb3a791ab544adcd3a5d0.zip
MdeModulePkg: Misc comments and DEBUG messages
Fixed some spelling typos in some comments. Added a couple of useful DEBUG messages Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: Samer El-Haj-Mahmoud <samer.el-haj-mahmoud@hp.com> Reviewed-by: Feng Tian <feng.tian@intel.com> git-svn-id: https://svn.code.sf.net/p/edk2/code/trunk/edk2@16450 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c')
-rw-r--r--MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c b/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
index 21c69ca6ef..4759579cab 100644
--- a/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
+++ b/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
@@ -257,7 +257,7 @@ SMM_IPL_EVENT_NOTIFICATION mSmmIplEvents[] = {
//
{ TRUE, FALSE, &gEfiSmmConfigurationProtocolGuid, SmmIplSmmConfigurationEventNotify, &gEfiSmmConfigurationProtocolGuid, TPL_NOTIFY, NULL },
//
- // Declare protocl notification on DxeSmmReadyToLock protocols. When this notification is etablished,
+ // Declare protocol notification on DxeSmmReadyToLock protocols. When this notification is established,
// the associated event is immediately signalled, so the notification function will be executed and the
// DXE SMM Ready To Lock Protocol will be found if it is already in the handle database.
//
@@ -659,7 +659,7 @@ SmmIplSmmConfigurationEventNotify (
/**
Event notification that is fired every time a DxeSmmReadyToLock protocol is added
- or if gEfiEventReadyToBootGuid is signalled.
+ or if gEfiEventReadyToBootGuid is signaled.
@param Event The Event that is being processed, not used.
@param Context Event Context, not used.
@@ -694,7 +694,7 @@ SmmIplReadyToLockEventNotify (
} else {
//
// If SMM is not locked yet and we got here from gEfiEventReadyToBootGuid being
// signalled, then gEfiDxeSmmReadyToLockProtocolGuid was not installed as expected.
// Print a warning on debug builds.
//
DEBUG ((DEBUG_WARN, "SMM IPL! DXE SMM Ready To Lock Protocol not installed before Ready To Boot signal\n"));
@@ -694,7 +694,7 @@ SmmIplReadyToLockEventNotify (
//
// If SMM is not locked yet and we got here from gEfiEventReadyToBootGuid being
- // signalled, then gEfiDxeSmmReadyToLockProtocolGuid was not installed as expected.
+ // signaled, then gEfiDxeSmmReadyToLockProtocolGuid was not installed as expected.
// Print a warning on debug builds.
//